.. rst-class:: detail

PrintText
====================

.. currentmodule:: compas_rrc

.. autoclass:: PrintText

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~PrintText.__init__
        ~PrintText.from_msg
    
    